-- Test program (physics)
-- **********************

-- Variables declaration
  oox, ooy = 25,25                                            -- Shape Offset
  pix, piy = 0,0                                              -- Shape position 
  correcbug = false
  objects = {}                                                -- Objects table

function love.load()                                          -- Game loading
  -- Create shape 
  ball_img = love.graphics.newImage("ball.png")               -- a nice ball...
  -- Resize screen
  sizedw, sizedh = 800, 400                                   -- set dimensions
  success = love.window.setMode( sizedw, sizedh )             -- Resize screen
  pix, piy = oox, sizedh-10-ooy                                   -- Set initial position in the bottom left of the window
  -- Initialiser la fenêtre
  love.graphics.setBackgroundColor( 255, 255, 255 )           -- Background color (white)
  love.window.setTitle("Problem with Physics")                        -- Set Title
  -- Initialise physics module
  love.physics.setMeter(64)                                   -- Definition: 64px/meter
  world = love.physics.newWorld(0, 9.81*64, true)             -- Create "realistic" world
  -- Create ground 
	objects.ground = {}
	objects.ground.body = love.physics.newBody( world, sizedw/2, sizedh-10/2, "static" )          -- Create body
    objects.ground.shape = love.physics.newRectangleShape( sizedw, 10)                            -- Create shape
    objects.ground.fixture = love.physics.newFixture( objects.ground.body, objects.ground.shape)  -- Link both
  -- Create floor  
	objects.floor = {}
	objects.floor.body = love.physics.newBody( world, sizedw/2, sizedh/2-10/2, "static" )         -- Create body
    objects.floor.shape = love.physics.newRectangleShape( sizedw/3, 10)                           -- Create shape
    objects.floor.fixture = love.physics.newFixture( objects.floor.body, objects.floor.shape)     -- Link both	
  -- Create ball
	objects.ball = {}
    objects.ball.body = love.physics.newBody(world, pix, piy, "dynamic")                          -- Create body
    objects.ball.shape = love.physics.newCircleShape( 0,0,25)                                     -- Create shape
    objects.ball.fixture = love.physics.newFixture( objects.ball.body, objects.ball.shape)        -- Link both
	--Objects.ball.body:setMass(1)                                                                 -- Set mass   

end

function love.update(dt)
  -- Manage ball move
  if love.keyboard.isDown("left") then
    -- Manage position
    pix=pix-dt*200                                            -- Go left
    if pix<= oox then                                         -- Stop if on the left side  
	  pix=oox
	end  
	-- Correction (bug ?)
    if correcbug == true then
	  objects.ball.body:applyLinearImpulse(0,0.01)	          -- Correct bug (ball stays at the floor level without falling)
    end  
  elseif love.keyboard.isDown("right") then
    -- Manage position
    pix=pix+dt*200                                            -- Go right
    if pix>= sizedw-oox then                                  -- Stop if on the right side 
	  pix=sizedw-oox 
	end  
	-- Correction (bug ?)
    if correcbug == true then
	  objects.ball.body:applyLinearImpulse(0,0.01)	          -- Correct bug (ball stays at the floor level without falling)
    end  
  end	
  -- Enable or disable correction instructions
  if love.keyboard.isDown("up") then                           -- Manage correction
    correcbug = not(correcbug)                                -- Invert status
  end
  -- Update dynamic world
  objects.ball.body:setX(pix)                                 -- Update ball position
  world:update(dt)                                            -- Update world
end

function love.draw()
  -- Draw ground
  love.graphics.setColor(72, 160, 14)                                                                 -- Set to green
  love.graphics.polygon("fill", objects.ground.body:getWorldPoints(objects.ground.shape:getPoints())) -- Draw ground 
  -- Draw floor  
  love.graphics.setColor(0, 0, 0)                                                                     -- Set to black
  love.graphics.polygon("fill", objects.floor.body:getWorldPoints(objects.floor.shape:getPoints()))   -- draw floor
  -- Draw ball
  love.graphics.setColor(255, 255, 255)
  love.graphics.draw(ball_img,objects.ball.body:getX(), objects.ball.body:getY(),0,1,1,oox,ooy)
  -- Print information about correcbug
  love.graphics.setColor(0, 0, 0)    
  love.graphics.print("Correcbug " .. tostring(correcbug),10,10)
end

function love.keypressed(k)
	if k == "space" then
	  objects.ball.body:applyLinearImpulse(0,-150)            -- Give a (vertical) kick to ball
	end
end
